@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,14 +35,15 @@ struct meal *meal_ptr;
 int max, meals, count, mealcount, meal = 0, deficnuts;
 int i, abacuscount, spacecount = 0, frcount, high_grams;
 char meal_date[9], inbuf[128];
-float newcal, ccals, fcals;
+float newcal;
 float deficpct[DV_COUNT], food_abacus[MAX_FOOD], serving_ratio_abacus[MAX_FOOD];
 int deficnut[DV_COUNT];
 float prodefic, thispct, totaldefic, serving_ratio;
 options.temp_meal_root = meal_ptr_origin;
 mealcount = meal_count(meal_ptr_origin);
 max = mealcount;
-set_defanal();
+if (specialheader) options.defanal = options.defanalrec;
+else options.defanal = options.defanalanal;
 if (options.defanal > 0 && options.defanal < mealcount) max = options.defanal;
 if (mealcount == 0)
  {
@@ -94,8 +95,7 @@ while (max > 0)
  spacer(19);
  if ( options.screen == 0 )
   {
-  if ( options.locknuts[ENERC_KCAL] || options.autocal ) printf("Type # of meals to analyze,  \"s\" for food suggestions,\n");
-  if ( !options.locknuts[ENERC_KCAL] && !options.autocal ) printf("Type # of meals to analyze,  \"s\" for food suggestions, \"c\" to reset calories,\n");
+  printf("Type # of meals to analyze,  \"s\" for food suggestions, \"c\" to reset calories,\n");
   printf("\"m\" to reset macronutrients, \"e\" to reset everything,  \"o\" to restore defaults,\n");
   printf("\"d\" for alternate displays,  or just press <enter> to quit:  ");
   }
@@ -103,123 +103,72 @@ while (max > 0)
  get_string(inbuf,127);
  if (strncmp(inbuf,"c",1) == 0)
   {
+  if (options.screen != 0) continue;
   if (!options.locknuts[ENERC_KCAL])
    {
    newcal = food_work.nutrient[ENERC_KCAL];
    options.abnuts[FAT] = 0;
    options.abnuts[FAMS] = 0;
-   if (strstr(inbuf,"/") != NULL)
-    {
-    ccals = 0;
-    fcals = 0;
-    ccals = atof(inbuf+2);
-    if (ccals > 0 && strstr(inbuf+2,"/") != NULL)
-     {
-     fcals = atof(strchr(inbuf+2,'/')+1);
-     if (fcals > 0)
-     newcal -= food_work.nutrient[CHO_KCAL] - ccals + food_work.nutrient[FAT_KCAL] - fcals;
-      {
-      if (!options.locknuts[CHOCDF])
-       {
-       options.abnuts[CHOCDF] = 0;
-       options.pccarb = 100 * ccals / newcal;
-       }
-      if (!options.locknuts[PROCNT])
-       {
-       options.abnuts[PROCNT] = 0;
-       options.pcprotein = 100 * food_work.nutrient[PROT_KCAL] / newcal;
-       }
-      if (!options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG] * ccals / food_work.nutrient[CHO_KCAL];
-      }
-     }
-    if (ccals > 0 && strstr(inbuf+2,"/") == NULL)
-     {
-     newcal -= food_work.nutrient[CHO_KCAL] - ccals;
-     if (!options.locknuts[CHOCDF])
-      {
-      options.abnuts[CHOCDF] = 0;
-      options.pccarb = 100 * ccals / newcal;
-      }
-     if (!options.locknuts[PROCNT])
-      {
-      options.abnuts[PROCNT] = 0;
-      options.pcprotein = 100 * food_work.nutrient[PROT_KCAL] / newcal;
-      }
-     if (!options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG] * ccals / food_work.nutrient[CHO_KCAL];
-     }
-    }
-   if (options.fatprotratio > 0 && options.abnuts[PROCNT]) options.pccarb = 0;
+   if (options.abnuts[PROCNT]) options.pccarb = 0;
    auto_cal(&newcal,1);
    }
   } 
  else if (strncmp(inbuf,"d",1) == 0) screen();
  else if (strncmp(inbuf,"p",1) == 0) screen_previous();
- else if (strncmp(inbuf,"e",1) == 0 )
+ else if (strncmp(inbuf,"e",1) == 0)
   {
-  if ( !options.locknuts[PROCNT] ) options.pcprotein = 0 ;
-  if ( !options.locknuts[PROCNT] ) options.fatprotratio = 0 ;
-  if ( !options.locknuts[CHOCDF] ) options.pccarb = 0 ;
+  if (options.screen != 0) continue;
+  restore_defaults(0);
   for ( i = 1; i < DVMap[0]; i++) if ( !options.locknuts[DVMap[i+1]]) options.abnuts[DVMap[i+1]] = food_work.nutrient[DVMap[i+1]];
-  if ( !options.locknuts[ENERC_KCAL] ) newcal = food_work.nutrient[ENERC_KCAL];
-  if (  options.locknuts[ENERC_KCAL] ) newcal = DV[ENERC_KCAL] ;
+  options.abnuts[FAMS] = 0;
+  if ( !options.locknuts[ENERC_KCAL] && !options.autocal) newcal = food_work.nutrient[ENERC_KCAL];
+  if (  options.locknuts[ENERC_KCAL] || options.autocal) newcal = DV[ENERC_KCAL];
   if ( !options.locknuts[FASAT] ) options.pcsatfat = 10 * food_work.nutrient[FASAT] / DVBase[FASAT] * DVBase[ENERC_KCAL] / newcal;
-  if ( options.fatprotratio > 0 && ( options.pcprotein > 0 || options.abnuts[PROCNT] > 0) ) options.abnuts[CHOCDF] = 0;
   auto_cal(&newcal,1);
   }
- else if (strncmp(inbuf,"m",1) == 0 )
+ else if (strncmp(inbuf,"m",1) == 0)
   {
-  if ( !options.locknuts[PROCNT] ) options.pcprotein = 0 ;
-  if ( !options.locknuts[PROCNT] ) options.fatprotratio = 0 ;
-  if ( !options.locknuts[CHOCDF] ) options.pccarb = 0 ;
-  if ( !options.locknuts[PROCNT]) options.abnuts[PROCNT] = food_work.nutrient[PROCNT];
-  if ( !options.locknuts[CHOCDF]) options.abnuts[CHOCDF] = food_work.nutrient[CHOCDF];
+  if (options.screen != 0) continue;
+  restore_defaults(0);
   if ( !options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG];
   if ( !options.locknuts[FASAT]) options.abnuts[FASAT] = food_work.nutrient[FASAT];
-  if ( !options.locknuts[FAPU]) options.abnuts[FAPU] = food_work.nutrient[FAPU];
-  if ( !options.locknuts[OMEGA6]) options.abnuts[OMEGA6] = food_work.nutrient[OMEGA6];
-  if ( !options.locknuts[LA]) options.abnuts[LA] = food_work.nutrient[LA];
-  if ( !options.locknuts[AA]) options.abnuts[AA] = food_work.nutrient[AA];
-  if ( !options.locknuts[OMEGA3]) options.abnuts[OMEGA3] = food_work.nutrient[OMEGA3];
-  if ( !options.locknuts[ALA]) options.abnuts[ALA] = food_work.nutrient[ALA];
-  if ( !options.locknuts[EPA]) options.abnuts[EPA] = food_work.nutrient[EPA];
-  if ( !options.locknuts[DHA]) options.abnuts[DHA] = food_work.nutrient[DHA];
-  if ( !options.locknuts[ENERC_KCAL]) newcal = food_work.nutrient[ENERC_KCAL];
-  if (  options.locknuts[ENERC_KCAL]) newcal = DV[ENERC_KCAL];
+  if ( !options.locknuts[PROCNT]) options.abnuts[PROCNT] = food_work.nutrient[PROCNT];
+  if ( !options.locknuts[CHOCDF]) options.abnuts[CHOCDF] = food_work.nutrient[CHOCDF];
+  if ( !options.locknuts[ENERC_KCAL] && !options.autocal) newcal = food_work.nutrient[ENERC_KCAL];
+  if (  options.locknuts[ENERC_KCAL] || options.autocal) newcal = DV[ENERC_KCAL];
   if ( !options.locknuts[FASAT] ) options.pcsatfat = 10 * food_work.nutrient[FASAT] / DVBase[FASAT] * DVBase[ENERC_KCAL] / newcal;
-  if ( options.fatprotratio > 0 && ( options.pcprotein > 0 || options.abnuts[PROCNT] > 0) ) options.abnuts[CHOCDF] = 0;
-  options.abnuts[FAT] = food_work.nutrient[FAT];
-  options.abnuts[FAMS] = food_work.nutrient[FAMS];
   auto_cal(&newcal,1);
   }
- else if (strncmp(inbuf,"n",1) == 0 )
+ else if (strncmp(inbuf,"o",1) == 0)
   {
-  if ( !options.locknuts[PROCNT] ) options.abnuts[PROCNT] = 0 ;
-  if ( !options.locknuts[PROCNT] ) options.fatprotratio = 0 ;
-  if ( !options.locknuts[CHOCDF] ) options.abnuts[CHOCDF] = 0 ;
+  if (options.screen != 0) continue;
+  restore_defaults(0);
+  }
+ else if (strncmp(inbuf,"n",1) == 0)
+  {
+  if (options.screen != 0) continue;
+  restore_defaults(0);
   if ( !options.locknuts[FIBTG]) options.abnuts[FIBTG] = food_work.nutrient[FIBTG];
+  if ( !options.locknuts[FASAT]) options.abnuts[FASAT] = food_work.nutrient[FASAT];
   if ( !options.locknuts[ENERC_KCAL] && !options.autocal)
    {
    newcal = food_work.nutrient[ENERC_KCAL];
    if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
    if ( !options.locknuts[CHOCDF]) options.pccarb = food_work.nutrient[CHO_KCAL] / food_work.nutrient[ENERC_KCAL] * 100;
+   if ( !options.locknuts[FASAT] ) options.pcsatfat = 10 * food_work.nutrient[FASAT] / DVBase[FASAT] * DVBase[ENERC_KCAL] / newcal;
    }
   if (  options.locknuts[ENERC_KCAL] || options.autocal)
    {
    newcal = DV[ENERC_KCAL];
    if ( !options.locknuts[PROCNT]) options.pcprotein = food_work.nutrient[PROT_KCAL] / DV[ENERC_KCAL] * 100;
    if ( !options.locknuts[CHOCDF]) options.pccarb = food_work.nutrient[CHO_KCAL] / DV[ENERC_KCAL] * 100;
-   }
-  if ( options.fatprotratio > 0 && ( options.pcprotein > 0 || options.abnuts[PROCNT] > 0) )
-   {
-   options.pccarb = 0;
-   options.abnuts[CHOCDF] = 0;
+   if ( !options.locknuts[FASAT] ) options.pcsatfat = 10 * food_work.nutrient[FASAT] / DVBase[FASAT] * DVBase[ENERC_KCAL] / newcal;
    }
   auto_cal(&newcal,1);
   }
- else if (strncmp(inbuf,"o",1) == 0 ) restore_defaults(0);
- else if (strncmp(inbuf,"s",1) == 0 )
+ else if (strncmp(inbuf,"s",1) == 0)
   {
-  if ( options.screen > 0) continue;
+  if (options.screen != 0) continue;
   header("NUT:  Food Suggestions");
   deficnuts = -1;
   totaldefic = 0;
@@ -230,7 +179,7 @@ while (max > 0)
       DVMap[count+1] == FAMS || DVMap[count+1] == FAPU || 
       DVMap[count+1] == CHOLE || DVMap[count+1] == OMEGA6 ||
       DVMap[count+1] == CHO_NONFIB || DVMap[count+1] == OMEGA3 ||
-      DVMap[count+1] == CHOCDF || DVMap[count+1] == VITD ||
+      DVMap[count+1] == CHOCDF ||
       food_work.nutrient[DVMap[count+1]] / DV[DVMap[count+1]] >= .9999) deficpct[count] = 0;
    else 
     {
@@ -254,9 +203,9 @@ while (max > 0)
    spacecount = 0;
    for (count = 0; count <= deficnuts; count++) 
     {
-    if (totaldefic >= 1) printf("%-31s%-15s %3.0f%%\n"," ",Nutrient[DVMap[deficnut[count]+1]],deficpct[count]);
-    else printf("%-31s%-15s %f%%\n"," ",Nutrient[DVMap[deficnut[count]+1]],deficpct[count]);
-    if (deficnuts > count && count == 16) printf("%-31s%-23s\n"," ","plus additional nutrients...");
+    if (totaldefic >= 1) printf("%-29s%-15s %6.0f%%\n"," ",Nutrient[DVMap[deficnut[count]+1]],deficpct[count]);
+    else printf("%-29s%-15s %f%%\n"," ",Nutrient[DVMap[deficnut[count]+1]],deficpct[count]);
+    if (deficnuts > count && count == 16) printf("%-29s%-23s\n"," ","plus additional nutrients...");
     if (deficnuts > count && count == 16) break;
     }
    spacer(deficnuts + 3);
@@ -282,21 +231,16 @@ while (max > 0)
       serving_ratio = deficpct[count] / thispct;
       if (serving_ratio < serving_ratio_abacus[abacuscount] && serving_ratio * food_ptr->grams > 14) serving_ratio_abacus[abacuscount] = serving_ratio;
       }
-     if (strstr(food_ptr->name,"HYDR") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"LEAVENING AGENTS") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"RENNIN,TABLETS") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"DEHYD") != NULL) high_grams = 114;
      if (strstr(food_ptr->name,"DRY") != NULL) high_grams = 114;
      if (strstr(food_ptr->name,"FROZEN DSSRT") != NULL) high_grams = 114;
-     if (strstr(food_ptr->name,"CEREALS RTE") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"ALASKA NATIVE") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"CEREALS") != NULL && strstr(food_ptr->name,"RTE") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"INFANT FORMULA") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"INF FORMULA") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"CHILD FORMULA") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"ENSURE PLUS") != NULL) serving_ratio_abacus[abacuscount] = 0;
-     if (strstr(food_ptr->name,"BABYFOOD") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"AK NATIVE") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"INST BRKFST PDR") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"ENSURE") != NULL) serving_ratio_abacus[abacuscount] = 0;
+     if (strstr(food_ptr->name,"MEATLESS") != NULL) serving_ratio_abacus[abacuscount] = 0;
      if (strstr(food_ptr->name,"MARGARINE") != NULL) high_grams = 14;
+     if (food_ptr->fdgrp == 2 || food_ptr->fdgrp == 3 || food_ptr->fdgrp == 8 || food_ptr->fdgrp == 14 || food_ptr->fdgrp == 19 || food_ptr->fdgrp == 25) serving_ratio_abacus[abacuscount] = 0;
      if (serving_ratio_abacus[abacuscount] > 1 && high_grams == 114) serving_ratio_abacus[abacuscount] = 1;
      if ((serving_ratio_abacus[abacuscount] * food_ptr->grams) > high_grams) serving_ratio_abacus[abacuscount] = high_grams / food_ptr->grams;
      for (count = 0; count <= deficnuts; count++)
@@ -312,7 +256,7 @@ while (max > 0)
     abacuscount = random_max_var_array(food_abacus, abacuscount);
     food_ptr = food_ptr_abacus[abacuscount];            
     food_recommended[++frcount] = food_ptr;
-    printf("%4.0f gm or %4.1f oz %-60s\n",serving_ratio_abacus[abacuscount] * food_ptr->grams,serving_ratio_abacus[abacuscount] * food_ptr->grams / 28.35,food_ptr->name);
+    printf("%4.0f gm or %4.1f oz %-60s\n",serving_ratio_abacus[abacuscount] * food_ptr->grams,serving_ratio_abacus[abacuscount] * food_ptr->grams / GRAMS_IN_OUNCE,food_ptr->name);
     spacecount++;
     if (spacecount == 19) break;
     totaldefic = 0;
@@ -334,6 +278,8 @@ while (max > 0)
   max = atoi(inbuf);
   if (max > 0) options.defanal = max;
   if (options.defanal == mealcount) options.defanal = 0;
+  if (specialheader) options.defanalrec = options.defanal;
+  if (!specialheader) options.defanalanal = options.defanal;
   write_OPTIONS();
   }
  }
