@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -137,12 +137,12 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 6;
-DVBase[AA] = 0.2;
+DVBase[LA] = 12;
+DVBase[AA] = 0.4;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 2.89;
-DVBase[EPA] = 0.33;
-DVBase[DHA] = 0.33;
+DVBase[ALA] = 2.22;
+DVBase[EPA] = 0.4;
+DVBase[DHA] = 0.4;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
 DVBase[FAPU] = DVBase[OMEGA6] + DVBase[OMEGA3];
 DVBase[FAMS] = 61.5 - DVBase[FASAT] - DVBase[FAPU];
@@ -383,7 +383,6 @@ else
     strncpy(buffer,bufptr,nlength);
     buffer[nlength] = '\0';
     }
-   else;
    }
   if (tokenunique == 1)
    {
@@ -480,7 +479,6 @@ else
    else if (i+(7*s)>l) printf(col[7],i,fsptr[i],i+s,fsptr[i+s],i+(2*s),fsptr[i+(2*s)],i+(3*s),fsptr[i+(3*s)],i+(4*s),fsptr[i+(4*s)],i+(5*s),fsptr[i+(5*s)],i+(6*s),fsptr[i+(6*s)]);
    else if (i+(8*s)>l) printf(col[8],i,fsptr[i],i+s,fsptr[i+s],i+(2*s),fsptr[i+(2*s)],i+(3*s),fsptr[i+(3*s)],i+(4*s),fsptr[i+(4*s)],i+(5*s),fsptr[i+(5*s)],i+(6*s),fsptr[i+(6*s)],i+(7*s),fsptr[i+(7*s)]);
    else if (i+(9*s)>l) printf(col[9],i,fsptr[i],i+s,fsptr[i+s],i+(2*s),fsptr[i+(2*s)],i+(3*s),fsptr[i+(3*s)],i+(4*s),fsptr[i+(4*s)],i+(5*s),fsptr[i+(5*s)],i+(6*s),fsptr[i+(6*s)],i+(7*s),fsptr[i+(7*s)],i+(8*s),fsptr[i+(8*s)]);
-   else;
    }
   spacer(savelinecount < 19 ? savelinecount : 19);
   printf("Type number of food category (\"b\" to go back, <enter> to quit):  ");
@@ -515,7 +513,7 @@ void food_show(struct food *food_ptr, float *ratio)
 char servingstring[62];
 int count;
 printf("%-60s   Grams  %8.2f\n",food_ptr->name,food_ptr->grams * *ratio);
-printf("Serving:  %-50s   Ounces  %7.2f\n",format_serving(servingstring,ratio,food_ptr),*ratio * food_ptr->grams / 28.35);
+printf("Serving:  %-50s   Ounces  %7.2f\n",format_serving(servingstring,ratio,food_ptr),*ratio * food_ptr->grams / GRAMS_IN_OUNCE);
 printf("          %-50s   Water    %6.2f%%\n"," ",food_ptr->nutrient[WATER] > 0 ? food_ptr->nutrient[WATER] : 0.0);
 if ( ! options.custom && options.screen == 0 ) printf("Percentages of \"Daily Values\" in this serving:                 Refuse   %3d%%\n\n",food_ptr->refuse);
 if ( options.custom && options.screen == 0 )     printf("Percentages of customized DV in this serving:                  Refuse   %3d%%\n\n",food_ptr->refuse);
@@ -589,7 +587,7 @@ food_work.refuse = 0;
 
 void food_display(FILE *fp)
 {
-int i;
+int i, n6;
 float pctfat = 0, pctcarb = 0, pctprot = 0;
 float p3, p6, h3, h6, o;
 char carbprotfat[9];
@@ -647,17 +645,14 @@ switch (options.screen)
  food_display_line(fp,ScreenMap[options.screen][i],0,0,0,4);
  food_display_line(fp,ScreenMap[options.screen][i+16],0,1,0,0);
  food_display_line(fp,ScreenMap[options.screen][13],0,0,0,0);
- if (!options.n6hufaspec) food_display_line(fp,ScreenMap[options.screen][13+16],0,1,0,0);
- if (options.n6hufaspec)
-  {
-  food_display_line(fp,ScreenMap[options.screen][13+16],0,0,0,0);
-  p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
-  p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
-  h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
-  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
-  o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
-  fprintf(fp,"Omega-6 HUFA     %5.1f%%\n",n6hufa(p3,p6,h3,h6,o));
-  }
+ food_display_line(fp,ScreenMap[options.screen][13+16],0,0,0,0);
+ p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
+ p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
+ h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
+ h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
+ o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
+ n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);
+ fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
  break;
  case 2 :
  fprintf(fp,"%-27s","Carbohydrates");
@@ -761,17 +756,14 @@ switch (options.screen)
  food_display_line(fp,ScreenMap[options.screen][i],1,0,0,4);
  food_display_line(fp,ScreenMap[options.screen][i+16],1,1,0,0);
  food_display_line(fp,ScreenMap[options.screen][13],1,0,0,0);
- if (!options.n6hufaspec) food_display_line(fp,ScreenMap[options.screen][13+16],1,1,0,0);
- if (options.n6hufaspec)
-  {
-  food_display_line(fp,ScreenMap[options.screen][13+16],1,0,0,0);
-  p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
-  p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
-  h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
-  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
-  o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
-  fprintf(fp,"Omega-6 HUFA     %5.0f%%\n",n6hufa(p3,p6,h3,h6,o));
-  }
+ food_display_line(fp,ScreenMap[options.screen][13+16],1,0,0,0);
+ p3 = 902 * food_work.nutrient[SHORT3] / food_work.nutrient[ENERC_KCAL];
+ p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
+ h3 = 902 * food_work.nutrient[LONG3] / food_work.nutrient[ENERC_KCAL];
+ h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
+ o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
+ n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);               
+ fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
  break;
  }
 }
@@ -879,6 +871,57 @@ while (recipe_ptr->next != NULL)
  }
 }
 
+void modify_label_food(int num, char *command)
+{
+struct food *m = NULL, *pm = NULL, *am = NULL, *po = NULL, *ao = NULL, *recipe_ptr = &recipe_root;
+int count = 0;
+int action;
+action = evaluate_action(command);
+if (num == action) return;
+while (recipe_ptr->next != NULL)
+ {
+ count++;
+ if (count == action && action > 0 && num > action)
+  {
+  ao = recipe_ptr;
+  po = recipe_ptr->next;
+  }
+ if (count == action && action > 0 && num < action)
+  {
+  ao = recipe_ptr->next;
+  if (recipe_ptr->next != NULL) po = recipe_ptr->next->next;
+  else po = NULL;
+  }
+ if (count == num)
+  {
+  m = recipe_ptr->next;
+  pm = recipe_ptr->next->next;
+  am = recipe_ptr;
+  if (action == 0)
+   {
+   recipe_ptr->next = recipe_ptr->next->next;
+   free(m);
+   return;
+   }
+  if (action < 0)
+   {
+   if (action == -1 && m->refuse >= 0) m->refuse++;
+   if (action == -1 && m->refuse <  0) m->refuse = 1;
+   if (action == -2 && m->refuse <= 0) m->refuse--;
+   if (action == -2 && m->refuse >  0) m->refuse = -1;
+   if (action == -3 && m->refuse <  0) m->refuse++;
+   if (action == -3 && m->refuse >  0) m->refuse--;
+   return;
+   }
+  }
+ recipe_ptr = recipe_ptr->next;
+ }
+if (num > count || action > count) return;
+am->next = pm;
+ao->next = m;
+m->next = po;
+}
+
 void compute_derived_fields(struct food *food_ptr)
 {
 float ratio;
@@ -971,7 +1014,7 @@ buffer[49] = '\0';
 return buffer;
 }
 
-float n6hufa(float p3, float p6, float h3, float h6, float o)
+float n6hufa(float p3, float p6, float h3, float h6, float o, float c)
 {
 float pc6 = .0441, pc3 = .0555, co = 5, ks = .175, hi3 = .005, hc6 = .7, hc3 = 3;
 float answer;
@@ -979,6 +1022,8 @@ float answer;
 printf("%f %f %f %f %f\n",p3,p6,h3,h6,o);
 exit(0);
 */  
+if (p3 == 0 && p6 == 0 && h3 == 0 && h6 == 0 && o == 0) return 0;
+if (c == 0) return 0;
 answer = 100 / (1 + pc6/p6 * (1 + p3/pc3 + h3/hi3 + o/co + p6/ks)) + 100 / (1 + hc6/h6 * (1 + h3/hc3));
 if (answer <= 90 && answer >= 15) return answer;
 if (answer > 90) return 90;
