@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,17 +29,20 @@
 
 struct opt options;
 
+static float DefaultTarget = 64, DefaultEPADHA = 2.2;
+
 void initialize_options()
 {
 int c;
 options.delopt = -1;
 options.defanal = 0;
+options.defanalanal = 0;
+options.defanalrec = 0;
 options.screen = 0;
 options.custom = 0;
 options.pcprotein = 0;
 options.pccarb= 0;
 options.pcsatfat = 0;
-options.fatprotratio = 0;
 options.protcalpergm = 4;
 options.carbcalpergm = 4;
 options.fatcalpergm = 9.2307692;
@@ -63,14 +66,11 @@ float buf = 0;
 int choice;
 options.abnuts[FAMS] = 0;
 header("NUT:  Set Personal Calorie Level");
-printf("\nCalorie level is set to %0.0f.\n\n",DV[ENERC_KCAL]);
-printf("\n1.  I will type a new calorie level.\n");
-printf("\n2.  I want to return to the program default of 2000.\n");
-printf("\n3.  I want NUT to automatically use my average calories, and when analyzing,\n");
-printf("    to automatically select an analysis period that contains that average\n");
-printf("    in order to even out day-to-day variation in the analysis.\n");
-printf("\n4.  I will retain the current calorie level without automatic features.\n");
-spacer(13);
+printf("\n  Calorie level is set to %0.0f.\n\n",DV[ENERC_KCAL]);
+printf("\n  1.  I will type a new calorie level.\n");
+printf("\n  2.  I want to return to the program default of 2000.\n");
+printf("\n  3.  I want NUT to automatically use the average calories from all my meals.\n");
+spacer(9);
 printf("\nEnter your choice (just <enter> to retain current setting):  ");
 choice = get_int();
 switch (choice)
@@ -99,10 +99,6 @@ switch (choice)
   options.abnuts[FAMS] = 0;
   options.autocal = 1;
   break;
- case 4 :
-  options.autocal = 0;
-  options.locknuts[ENERC_KCAL] = 1;
-  break;
  case 2 :
   options.locknuts[ENERC_KCAL] = 0;
   options.abnuts[ENERC_KCAL] = 0;
@@ -119,29 +115,79 @@ header("NUT:  Set Personal Calorie Level");
 new_nut_levels();
 }
    
-void efa_method()
+void efa_options()
 {
 char buf[128];
-float temp, lastsetting;
-lastsetting = options.abnuts[FAPU];
-header("NUT:  Essential Fats Absolute Amount");
-spacer(0);
-options.n6hufaspec = 0;
-printf("\nEnter absolute amount of EFAs in grams (just <enter> for default):  ");
-get_string(buf,127);
-options.abnuts[FAPU] = atof(buf);
-options.locknuts[FAPU] = 1;
-if ( options.abnuts[FAPU] < 0 ) 
+int menu_choice;
+float tempfloat;
+
+while (1)
  {
- if (options.abnuts[FAPU] == -1) options.n6hufaspec = 1;
- options.abnuts[FAPU] = 0;
- options.locknuts[FAPU] = 0;
+ header("NUT:  Essential Fatty Acid Options");
+ printf("\n\n");
+ if (options.locknuts[FAPU] != 1) printf("           1.  Accept current reference values as absolute amounts.\n\n");
+ else printf("           1.  Allow reference values to change with analysis resets.\n\n");
+ if (options.locknuts[FAPU] != 1) printf("           2.  Change target for Omega-6/3 Balance (currently %2.0f/%2.0f).\n\n",options.n6hufa == 0 ? DefaultTarget : options.n6hufa,options.n6hufa == 0 ? 100 - DefaultTarget : 100 - options.n6hufa);
+ if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
+ if (options.locknuts[FAPU] != 1) printf("\n\n\n      If you change options #2 or #3, you will have to reset the analysis\n");
+ if (options.locknuts[FAPU] != 1) printf("      screen with a \"c\", \"m\", or \"o\" to have the new settings take effect.\n");
+ if (options.locknuts[FAPU] != 1) spacer(13);
+ else spacer(4);
+ printf("\nEnter your choice (just <enter> to quit):  ");
+ menu_choice = get_char();
+ switch (menu_choice)
+  {
+
+  case '1' : efa_method();
+             write_OPTIONS();
+             break;
+
+  case '2' : 
+  header("NUT:  Essential Fatty Acid Options");
+  printf("\n\n");
+  if (options.locknuts[FAPU] != 1) printf("           1.  Accept current reference values as absolute amounts.\n\n");
+  else printf("           1.  Allow reference values to change with analysis resets.\n\n");
+  if (options.locknuts[FAPU] != 1) printf("           2.  Change target for Omega-6/3 Balance (currently %2.0f/%2.0f).\n\n",options.n6hufa == 0 ? DefaultTarget : options.n6hufa,options.n6hufa == 0 ? 100 - DefaultTarget : 100 - options.n6hufa);
+  if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
+  if (options.locknuts[FAPU] != 1) spacer(8);
+  else spacer(4);
+  printf("\nEnter new Omega-6 percentage (15-90):  ");
+  get_string(buf,127);
+  tempfloat = atof(buf);
+  if (tempfloat < 15 || tempfloat > 90) break;
+  else options.n6hufa = tempfloat;
+  write_OPTIONS();
+  break;                 
+
+  case '3' : 
+  header("NUT:  Essential Fatty Acid Options");
+  printf("\n\n");
+  if (options.locknuts[FAPU] != 1) printf("           1.  Accept current reference values as absolute amounts.\n\n");
+  else printf("           1.  Allow reference values to change with analysis resets.\n\n");
+  if (options.locknuts[FAPU] != 1) printf("           2.  Change target for Omega-6/3 Balance (currently %2.0f/%2.0f).\n\n",options.n6hufa == 0 ? DefaultTarget : options.n6hufa,options.n6hufa == 0 ? 100 - DefaultTarget : 100 - options.n6hufa);
+  if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
+  if (options.locknuts[FAPU] != 1) spacer(8);
+  else spacer(4);
+  printf("\nEnter new EPA+DHA maximum grams:  ");
+  get_string(buf,127);
+  tempfloat = atof(buf);
+  if (tempfloat <= 0) break;
+  else options.epadhamax = tempfloat;
+  write_OPTIONS();
+  break; 
+
+  default  : return;
+  }
  }
-options.abnuts[FAT] = 0;
-options.abnuts[FAMS] = 0;
-if (options.abnuts[FAPU] == 0) 
+}
+
+void efa_method()
+{
+if (options.locknuts[FAPU] == 1)
  {
- options.locknuts[FAPU] = 0;
+ options.abnuts[FAT] = 0;
+ options.abnuts[FAMS] = 0;
+ options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
  options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
  options.abnuts[LA] = 0; options.locknuts[LA] = 0;
  options.abnuts[AA] = 0; options.locknuts[AA] = 0;
@@ -149,32 +195,18 @@ if (options.abnuts[FAPU] == 0)
  options.abnuts[ALA] = 0; options.locknuts[ALA] = 0;
  options.abnuts[EPA] = 0; options.locknuts[EPA] = 0;
  options.abnuts[DHA] = 0; options.locknuts[DHA] = 0;
+ return;
  }
-if ( options.abnuts[FAPU] > 0 && lastsetting <= 0)
- {
- temp = options.abnuts[FAPU] / DVBase[FAPU];
- options.abnuts[OMEGA6] = temp * DVBase[OMEGA6]; options.locknuts[OMEGA6] = 1;
- options.abnuts[LA] = temp * DVBase[LA]; options.locknuts[LA] = 1;
- options.abnuts[AA] = temp * DVBase[AA]; options.locknuts[AA] = 1;
- options.abnuts[OMEGA3] = temp * DVBase[OMEGA3]; options.locknuts[OMEGA3] = 1;
- options.abnuts[ALA] = temp * DVBase[ALA]; options.locknuts[ALA] = 1;
- options.abnuts[EPA] = temp * DVBase[EPA]; options.locknuts[EPA] = 1;
- options.abnuts[DHA] = temp * DVBase[DHA]; options.locknuts[DHA] = 1;
- }
-if ( options.abnuts[FAPU] > 0 && lastsetting >  0)
- {
- temp = options.abnuts[FAPU] / lastsetting;
- options.abnuts[OMEGA6] = temp * options.abnuts[OMEGA6]; options.locknuts[OMEGA6] = 1;
- options.abnuts[LA] = temp * options.abnuts[LA]; options.locknuts[LA] = 1;
- options.abnuts[AA] = temp * options.abnuts[AA]; options.locknuts[AA] = 1;
- options.abnuts[OMEGA3] = temp * options.abnuts[OMEGA3]; options.locknuts[OMEGA3] = 1;
- options.abnuts[ALA] = temp * options.abnuts[ALA]; options.locknuts[ALA] = 1;
- options.abnuts[EPA] = temp * options.abnuts[EPA]; options.locknuts[EPA] = 1;
- options.abnuts[DHA] = temp * options.abnuts[DHA]; options.locknuts[DHA] = 1;
- }
+ 
+options.abnuts[FAPU] = DV[FAPU]; options.locknuts[FAPU] = 1;
+options.abnuts[OMEGA6] = DV[OMEGA6]; options.locknuts[OMEGA6] = 1;
+options.abnuts[LA] = DV[LA]; options.locknuts[LA] = 1;
+options.abnuts[AA] = DV[AA]; options.locknuts[AA] = 1;
+options.abnuts[OMEGA3] = DV[OMEGA3]; options.locknuts[OMEGA3] = 1;
+options.abnuts[ALA] = DV[ALA]; options.locknuts[ALA] = 1;
+options.abnuts[EPA] = DV[EPA]; options.locknuts[EPA] = 1;
+options.abnuts[DHA] = DV[DHA]; options.locknuts[DHA] = 1;
 auto_cal(&DV[ENERC_KCAL],0);
-header("NUT:  Essential Fats Absolute Amounts");
-new_nut_levels();
 }
 
 void protein_percent()
@@ -188,14 +220,13 @@ options.pcprotein = atof(buf);
 if ( options.pcprotein <= 0 || (options.pcprotein + options.pccarb) > 90 )
  {
  options.pcprotein = 0;
- if (options.fatprotratio == 0 && options.abnuts[PROCNT] == 0) options.locknuts[PROCNT] = 0;
+ if (options.abnuts[PROCNT] == 0) options.locknuts[PROCNT] = 0;
  }
 if ( options.pcprotein > 0 )
  {
  options.abnuts[PROCNT] = 0;
  options.locknuts[PROCNT] = 1;
  }
-if ( options.pcprotein > 0 && (options.pccarb > 0 || options.abnuts[CHOCDF] > 0)) options.fatprotratio = 0;
 options.abnuts[FAT] = 0;
 options.locknuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
@@ -205,37 +236,6 @@ header("NUT:  Protein Percentage");
 new_nut_levels();
 }
 
-void fatprot_ratio()
-{
-char buf[128];
-header("NUT:  Fat to Protein Ratio");
-spacer(0);
-printf("\nEnter ratio of fat to protein calories (just <enter> for default):  ");
-get_string(buf,127);
-options.fatprotratio = atof(buf);
-if ( options.fatprotratio <= 0 ) options.fatprotratio = 0;
-if ( options.fatprotratio == 0 && options.pcprotein == 0 && options.abnuts[PROCNT] == 0 ) options.locknuts[PROCNT] = 0;
-if ( (options.pcprotein > 0 || options.abnuts[PROCNT] > 0) && (options.pccarb > 0 || options.abnuts[CHOCDF] > 0) ) options.fatprotratio = 0;
-if ( options.fatprotratio > 0 ) 
- {
- options.locknuts[PROCNT] = 1; 
- if (options.abnuts[PROCNT] > 0 || options.pcprotein > 0)
-  {
-  options.pccarb = 0;
-  options.abnuts[CHOCDF] = 0;
-  options.locknuts[CHOCDF] = 0;
-  }
- else if (options.abnuts[CHOCDF] == 0 && options.pccarb == 0) options.pcprotein = 30 / options.fatprotratio;
- }
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
-options.abnuts[FAMS] = 0;
-options.locknuts[FAMS] = 0;
-auto_cal(&DV[ENERC_KCAL],0);
-header("NUT:  Fat to Protein Ratio");
-new_nut_levels();
-}
-
 void carb_percent()
 {
 char buf[128];
@@ -251,7 +251,6 @@ if ( options.pccarb <= 0 || (options.pcprotein + options.pccarb) > 90 )
  options.locknuts[CHOCDF] = 0;
  }
 if ( options.pccarb > 0 ) options.abnuts[CHOCDF] = 0;
-if ( options.pccarb > 0 && (options.pcprotein > 0 || options.abnuts[PROCNT] > 0)) options.fatprotratio = 0;
 options.abnuts[FAT] = 0;
 options.locknuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
@@ -295,12 +294,11 @@ options.abnuts[PROCNT] = atof(buf);
 if ( options.abnuts[PROCNT] <= 0 )
  {
  options.abnuts[PROCNT] = 0;
- if (options.pcprotein == 0 && options.fatprotratio == 0) options.locknuts[PROCNT] = 0;
+ if (options.pcprotein == 0) options.locknuts[PROCNT] = 0;
  }
 if ( options.abnuts[PROCNT] > 0 )
  {
  options.pcprotein = 0;
- if (options.abnuts[CHOCDF] != 0) options.fatprotratio = 0;
  options.locknuts[PROCNT] = 1;
  }
 options.abnuts[FAT] = 0;
@@ -327,7 +325,6 @@ if ( options.abnuts[CHOCDF] > 0 )
  options.pccarb = 0;
  options.locknuts[CHOCDF] = 1;
  }
-if (options.abnuts[CHOCDF] > 0 && (options.pcprotein > 0 || options.abnuts[PROCNT] > 0)) options.fatprotratio = 0;
 options.abnuts[FAT] = 0;
 options.locknuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
@@ -380,7 +377,7 @@ fgets(buff,128,stdin);
 
 void auto_cal(float *bufptr, int analflag)
 {
-float buf = *bufptr, temp = 0, lowcarbsatfatchangeover = 0.30;
+float buf = *bufptr, temp = 0;
 int i;
 if (options.autocal) buf = average_cals();
 if (analflag)
@@ -434,19 +431,7 @@ if (options.pcprotein > 0) DV[PROCNT] = options.pcprotein / 100 * DV[ENERC_KCAL]
 if (options.abnuts[PROCNT] > 0) DV[PROCNT] = options.abnuts[PROCNT];
 if (options.pccarb > 0) DV[CHOCDF] = options.pccarb / 100 * DV[ENERC_KCAL] / options.carbcalpergm;
 if (options.abnuts[CHOCDF] > 0) DV[CHOCDF] = options.abnuts[CHOCDF];
-if (options.fatprotratio > 0 && options.abnuts[PROCNT] <= 0 && options.pcprotein <= 0)
- {
- temp = 1 - (DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
- DV[PROCNT] = temp * DV[ENERC_KCAL] / (options.fatprotratio + 1) / options.protcalpergm;
- DV[FAT] = DV[PROCNT] * options.fatprotratio / (options.fatcalpergm / options.protcalpergm) ;
- }
-if (options.fatprotratio > 0 && (options.abnuts[PROCNT] > 0 || options.pcprotein > 0))
- {
- DV[FAT] = DV[PROCNT] * options.fatprotratio / (options.fatcalpergm / options.protcalpergm) ;
- temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[FAT] * options.fatcalpergm) / DV[ENERC_KCAL];
- DV[CHOCDF] = temp * DV[ENERC_KCAL] / options.carbcalpergm;
- }
-if (options.fatprotratio <= 0 && (DV[PROCNT] != DVBase[PROCNT] || DV[CHOCDF] != DVBase[CHOCDF]))
+if (DV[PROCNT] != DVBase[PROCNT] || DV[CHOCDF] != DVBase[CHOCDF])
  {
  temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
  DV[FAT] = temp * DV[ENERC_KCAL] / options.fatcalpergm;
@@ -512,21 +497,7 @@ if (options.abnuts[NA] > 0) DV[NA] = options.abnuts[NA];
 if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN]; 
 if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
 else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
-temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
-if (temp > lowcarbsatfatchangeover && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
- {
- temp = (0.3 / lowcarbsatfatchangeover * DV[FASAT] * temp / 0.3) - DV[FASAT];
- DV[FASAT] += temp;
- DV[FAMS] -= temp;
- if (analflag && food_work.nutrient[FASAT] < DV[FASAT])
- /* if (analflag) */
-  {
-  temp = (DV[FASAT] + DV[FAMS]) / (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]);
-  DV[FASAT] = food_work.nutrient[FASAT] * temp;
-  DV[FAMS] = food_work.nutrient[FAMS] * temp;
-  }
- }
-if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.fatprotratio || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
+if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
 else options.custom = 0;
 write_OPTIONS();
 }
@@ -606,103 +577,24 @@ void restore_defaults(int removelock)
 int i;
 if ( removelock ) for ( i = 0; i < NUTRIENT_COUNT ; i++ ) options.locknuts[i] = 0;
 if ( !options.locknuts[PROCNT] ) options.pcprotein = 0;
-if ( !options.locknuts[PROCNT] ) options.fatprotratio = 0;
 if ( !options.locknuts[CHOCDF] ) options.pccarb = 0;
 if ( !options.locknuts[FASAT] ) options.pcsatfat = 0;
-if ( removelock ) options.autocal = 0;
-if ( removelock ) options.n6hufaspec = 0;
+if ( removelock )
+ {
+ options.autocal = 0;
+ options.n6hufa = 0;
+ options.epadhamax = 0;
+ }
 for ( i = 0; i < NUTRIENT_COUNT ; i++ ) if ( !options.locknuts[i] ) options.abnuts[i] = 0;
 if ( !options.locknuts[ENERC_KCAL] ) auto_cal(&DVBase[ENERC_KCAL],removelock ? 0 : 1);
 else auto_cal(&options.abnuts[ENERC_KCAL],removelock ? 0 : 1);
 }
 
-void set_defanal()
-{
-struct meal *meal_ptr = options.temp_meal_root;
-int count = 0;
-char lastdate[9];
-int lastmeal;
-float thisresult = -1, lastresult;
-int lastresultcount = 0;
-float sum = 0, testthis, testlast;
-if (!options.autocal) return;
-auto_cal(&DV[ENERC_KCAL],0);
-if (meal_count(meal_ptr) < options.mealsperday * 5) return;
-if (meal_ptr->next == NULL) return;
-strcpy(lastdate,meal_ptr->next->meal_date);
-lastmeal = meal_ptr->next->meal;
-count = 0;
-while (meal_ptr->next != NULL)
- {
- meal_ptr = meal_ptr->next;
- sum += meal_ptr->grams / 100 * FoodIndex[meal_ptr->food_no]->nutrient[ENERC_KCAL];
- if (meal_ptr->next != NULL) if (strcmp(lastdate,meal_ptr->next->meal_date) != 0 || lastmeal != meal_ptr->next->meal)
-  {
-  count++;
-  strcpy(lastdate,meal_ptr->next->meal_date);
-  lastmeal = meal_ptr->next->meal;
-  if (count % options.mealsperday == 0 && count >= options.mealsperday * 5)
-   {
-   lastresult = thisresult;
-   lastresultcount = count - options.mealsperday;
-   thisresult = (sum / count * options.mealsperday / DV[ENERC_KCAL]) - 1;
-   if (lastresult == -1)
-    {
-    lastresult = thisresult;
-    lastresultcount = count;
-    }
-   else
-    {
-    if ((lastresult <= 0.0 && thisresult >= 0.0) || (lastresult >= 0.0 && thisresult <= 0.0))
-     {
-     testthis = thisresult < 0 ? thisresult * -1.0 : thisresult;
-     testlast = lastresult < 0 ? lastresult * -1.0 : lastresult;
-     options.defanal = testthis > testlast ? lastresultcount : count;
-     return;
-     }
-    }
-   }
-  }
- if (meal_ptr->next == NULL)
-  {
-  count++;
-  if (count % options.mealsperday == 0 && count >= options.mealsperday * 5)
-   {
-   lastresult = thisresult;
-   lastresultcount = count - options.mealsperday;
-   thisresult = (sum / count * options.mealsperday / DV[ENERC_KCAL]) - 1;
-   if (lastresult == -1)
-    {
-    lastresult = thisresult;
-    lastresultcount = count;
-    }
-   else
-    {
-    if ((lastresult <= 0.0 && thisresult >= 0.0) || (lastresult >= 0.0 && thisresult <= 0.0))
-     {
-     testthis = thisresult < 0 ? thisresult * -1.0 : thisresult;
-     testlast = lastresult < 0 ? lastresult * -1.0 : lastresult;
-     options.defanal = testthis > testlast ? lastresultcount : count;
-     return;
-     }
-    }
-   }
-  }
- }
-options.defanal = count - count % options.mealsperday;
-}
-
 void efa_dynamics()
 {
 int i;
 float temp, temp1, temp_la = 0, temp_aa = 0, hufapct, p3, h3, h6, p6, o;
-float target = 75, epadhalimit = 1.0, extra_ala;
-
-/*
-DV[ALA] = food_work.nutrient[ALA];
-if (DV[ALA] <= 0) DV[ALA] = .00001;
-*/
-if (food_work.nutrient[ALA] > DV[ALA]) DV[ALA] = food_work.nutrient[ALA];
+float target = DefaultTarget, epadhalimit, extra_ala;
 
 if (options.n6hufa != 0)
  {
@@ -710,6 +602,19 @@ if (options.n6hufa != 0)
  if (options.n6hufa > 90) options.n6hufa = 90;
  }
 
+if (options.epadhamax <= 0) epadhalimit = DefaultEPADHA;
+else epadhalimit = options.epadhamax;
+if (options.n6hufa != 0) target = options.n6hufa;
+  
+/*
+DV[ALA] = food_work.nutrient[ALA];
+if (DV[ALA] <= 0) DV[ALA] = .00001;
+*/
+  
+  
+if (food_work.nutrient[ALA] > DV[ALA]) DV[ALA] = food_work.nutrient[ALA];
+  
+
 options.abnuts[AA] = food_work.nutrient[AA];
 options.abnuts[LA] = food_work.nutrient[LA];
 options.abnuts[ALA] = DV[ALA];
@@ -723,10 +628,9 @@ if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.
  {
  temp = i * .001;
  h3 = 902 * temp / food_work.nutrient[ENERC_KCAL];
- hufapct = n6hufa(p3,p6,h3,h6,o);
+ hufapct = n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);
 
- if (options.n6hufa <= 0 && hufapct > target) continue;
- if (options.n6hufa > 0 && hufapct > options.n6hufa) continue;
+ if (hufapct > target) continue;
 
  options.abnuts[OMEGA6] = food_work.nutrient[SHORT6] + food_work.nutrient[LONG6];
  options.abnuts[OMEGA3] = food_work.nutrient[SHORT3] + extra_ala + temp;
@@ -746,9 +650,8 @@ if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.
    {
    temp_la = p6 * i * .00001;
    temp_aa = h6 * i * .00001;
-   hufapct = n6hufa(p3,p6-temp_la,h3,h6-temp_aa,o);
-   if (options.n6hufa <= 0 && hufapct < target) break;
-   if (options.n6hufa > 0 && hufapct < options.n6hufa) break;
+   hufapct = n6hufa(p3,p6-temp_la,h3,h6-temp_aa,o,food_work.nutrient[ENERC_KCAL]);
+   if (hufapct < target) break;
    }
   options.abnuts[LA] -= temp_la / 902 * food_work.nutrient[ENERC_KCAL];
   temp_aa = 902 / food_work.nutrient[ENERC_KCAL] * food_work.nutrient[AA] * (1 - (options.abnuts[LA] / food_work.nutrient[LA]));
@@ -772,10 +675,9 @@ else
 
   p3 = 902 * temp / food_work.nutrient[ENERC_KCAL];
   o  = 902 * (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]) / food_work.nutrient[ENERC_KCAL];
-  hufapct = n6hufa(p3,p6,h3,h6,o);
+  hufapct = n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);
 
-  if (options.n6hufa <= 0 && hufapct > target) continue;
-  if (options.n6hufa > 0 && hufapct > options.n6hufa) continue;
+  if (hufapct > target) continue;
   options.abnuts[OMEGA6] = food_work.nutrient[SHORT6] + food_work.nutrient[LONG6];
   options.abnuts[OMEGA3] = food_work.nutrient[LONG3] + temp;
   temp -= food_work.nutrient[SHORT3] - food_work.nutrient[ALA];
